============================
Djblets 0.7.21 Release Notes
============================

**Release date**: October 11, 2013


djblets.webapi
==============

* Added a :py:func:`has_list_access_permissions` function, which is used to
  determine access to a list resource.


Contributors
============

* Christian Hammond
* David Trowbridge
